/**
 * Retrieves the translation of text.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/packages/packages-i18n/
 */
import { __ } from '@wordpress/i18n';

/**
 * React hook that is used to mark the block wrapper element.
 * It provides all the necessary props like the class name.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/packages/packages-block-editor/#useblockprops
 */
import { useBlockProps } from '@wordpress/block-editor';

/**
 * All custom used components, third party imports
 *
 */
import { useEffect, useRef } from '@wordpress/element';
import { createShape } from './progressbar';
import InspectorSettings from './inspector-settings';

/**
 * The edit function describes the structure of your block in the context of the
 * editor. This represents what the editor will render when the block is used.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/block-api/block-edit-save/#edit
 *
 * @return {Element} Element to render.
 */
export default function Edit(props) {
	const {attributes} = props

	const blockProps = useBlockProps()
	 const junoContainerRef = useRef(null)
	  useEffect(() => {
	  	const progressBar = createShape(junoContainerRef.current, attributes);
	    // Clean up the progress bar when the component is unmounted
	    return () => {
	      // You may add any cleanup logic here if needed
	    	progressBar.destroy()
	    };
	  }, [attributes]);

	  return (
	  	<div { ...blockProps }>
		  	<InspectorSettings
						{...props}
					/>
		    <div ref={junoContainerRef} className="juno juno-container"></div>
	    </div>
	  );
}
