/**
 * React hook that is used to mark the block wrapper element.
 * It provides all the necessary props like the class name.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/packages/packages-block-editor/#useblockprops
 */
import { useBlockProps } from '@wordpress/block-editor';

/**
 * The save function defines the way in which the different attributes should
 * be combined into the final markup, which is then serialized by the block
 * editor into `post_content`.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/block-api/block-edit-save/#save
 *
 * @return {Element} Element to render.
 */

export default function save({attributes}) {
	const {
		shapeType,
		enableText, 
		percentile, 
		shapeAnimation, 
		animationDuration, 
		size, 
		textColor, 
		fillColor, 
		strokeColor, 
		strokeWidth, 
		trailColor, 
		trailWidth
	} = attributes

	return (
		<div { ...useBlockProps.save() }>
			<div className="juno juno-container"
				data-shape-type={shapeType}
				data-enable-text={enableText}
				data-percentile={percentile}
				data-shape-animation={shapeAnimation}
				data-animation-duration={animationDuration}
				data-size={size}
				data-text-color={textColor}
				data-fill-color={fillColor}
				data-stroke-color={strokeColor}
				data-stroke-width={strokeWidth}
				data-trail-color={trailColor}
				data-trail-width={trailWidth}
			></div>
		</div>
	);
}
